@@ -51,8 +51,6 @@ def init(session_maker, **kwargs):
     @type kwargs: dict
     """
     
-    # Bind engine
-    metadata.bind = session_maker.bind
     # Setup model
     setup_tables()
     setup_mappers(**kwargs)
@@ -221,15 +219,15 @@ def setup_events(session_maker, **kwargs):
     event.listen(mapping['element']._children, 'append', mapping['element']._children_added)
     event.listen(mapping['element']._children, 'remove', mapping['element']._children_removed)
     event.listen(session_maker, 'before_flush', _session_before_flush)
-    event.listen(Engine, "begin", _sqlite_begin)
+    if session_maker.bind.name == 'sqlite':
+        event.listen(session_maker.bind, 'begin', _sqlite_begin)
 
 def _sqlite_begin(conn):
-    if conn.engine.name == 'sqlite':
-        # Foreign keys are NOT enabled by default... WTF!
-        conn.execute("PRAGMA foreign_keys = ON")
-        # Force a single active transaction on a sqlite database.
-        # This is needed to emulate FOR UPDATE locks :(
-        conn.execute("BEGIN EXCLUSIVE")
+    # Foreign keys are NOT enabled by default... WTF!
+    conn.execute("PRAGMA foreign_keys = ON")
+    # Force a single active transaction on a sqlite database.
+    # This is needed to emulate FOR UPDATE locks :(
+    conn.execute("BEGIN EXCLUSIVE")
 
 def _session_before_flush(session, flush_context, instances):
     """
