@@ -28,7 +28,7 @@ def setup():
     base.BaseTest._session_maker = scoped_session(sessionmaker(bind=engine))
     multivac.init(base.BaseTest._session_maker)
     
-    multivac.metadata.create_all()
+    multivac.metadata.create_all(engine)
 
 def teardown():
     #multivac.metadata.drop_all()
